/* === Science & Technology Consultants (SciTeX) = Fri-03-10-2006 === */

/* --- Parameters --------------------------------------------------- */

Include "Test-2D.par";

/* --- Groups ------------------------------------------------------- */

Group {
/* ... Volume ....................................................... */

  VolDskA = Region[6001]; // Disk A
  VolDskB = Region[6002]; // Disk B

/* ... Surface ...................................................... */

  SfcBtmA = Region[5001]; // Bottom A
  SfcSdeA = Region[5002]; // Side A
  SfcTopA = Region[5003]; // Top A
  SfcBtmB = Region[5004]; // Bottom B
  SfcSdeB = Region[5005]; // Side B
  SfcTopB = Region[5006]; // Top B

/* ... Domain ....................................................... */

  SfcA = Region[{SfcBtmA,SfcSdeA,SfcTopA}] ;
  VolA = Region[{VolDskA}] ;
  SfcB = Region[{SfcBtmB,SfcSdeB,SfcTopB}] ;
  VolB = Region[{VolDskB}] ;

  DmnA = Region[{SfcA,VolA}];
  DmnB = Region[{SfcB,VolB}];
}

/* --- Functions ---------------------------------------------------- */

Function {
/* ... Time ......................................................... */

//  TmeFct[] = ($Time < 1.0) ? 0.0 : 1.0;

/* ... Save ......................................................... */

  SveFct[] = !($TimeStep % 1);

/* ... Volume Properties ............................................ */

  MasDen[VolDskA]    = 2330.0;
  HeaCap[VolDskA]    =  507.0;
  TheCon[VolDskA]    =  148.0;

  MasDen[VolDskB]    = 2330.0;
  HeaCap[VolDskB]    =  507.0;
  TheCon[VolDskB]    =  148.0;

/* ... Volume Drivers ............................................... */

  HeaPwr[VolDskA]    = 0.0;

  HeaPwr[VolDskB]    = 0.0;

/* ... Surface Drivers .............................................. */

  HeaFlx[SfcBtmA]    = 0.0;
  HeaFlx[SfcSdeA]    = 0.0;
  HeaFlx[SfcTopA]    = 0.0;

  HeaFlx[SfcBtmB]    = 0.0;
  HeaFlx[SfcSdeB]    = 0.0;
  HeaFlx[SfcTopB]    = Flx * (1.0 - (X[]/Rds)^2);
//  HeaFlx[SfcTopB]    = Flx * TmeFct[] * (1.0 - (X[]/Rds)^2);

/* ... Surface Convection ........................................... */

  HTCCvn[SfcBtmA] = 10.0;
  TmpCvn[SfcBtmA] = TmpIni;
  HTCCvn[SfcSdeA] = 10.0;
  TmpCvn[SfcSdeA] = TmpIni;
  HTCCvn[SfcTopA] = 10.0;
  TmpCvn[SfcTopA] = TmpIni;

  HTCCvn[SfcBtmB] = 10.0;
  TmpCvn[SfcBtmB] = TmpIni;
  HTCCvn[SfcSdeB] = 10.0;
  TmpCvn[SfcSdeB] = TmpIni;
  HTCCvn[SfcTopB] = 10.0;
  TmpCvn[SfcTopB] = TmpIni;

/* ... Surface Radiation ............................................ */

  HTCRdn[SfcBtmA]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcBtmA]   = TmpIni;
  HTCRdn[SfcSdeA]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcSdeA]   = TmpIni;
  HTCRdn[SfcTopA]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcTopA]   = TmpIni;

  HTCRdn[SfcBtmB]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcBtmB]   = TmpIni;
  HTCRdn[SfcSdeB]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcSdeB]   = TmpIni;
  HTCRdn[SfcTopB]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcTopB]   = TmpIni;
}

/* --- Constraint --------------------------------------------------- */

Constraint {
  {Name TmpCon;
    Case {
//      {Region SfcBtm; Type Assign; Value TmpIni;}
//      {Region SfcSde; Type Assign; Value TmpIni;}
//      {Region SfcTop; Type Assign; Value TmpIni;}
      {Region DmnA; Type Init; Value TmpIni;}
      {Region DmnB; Type Init; Value TmpIni;}
    }
  }
}

/* --- General Thermal Problem Solver ------------------------------- */

Include "Test-2D.sol";

/* --- Post Operation ----------------------------------------------- */

PostOperation {
  {Name Tmp3D; NameOfPostProcessing TmpPst;
    Operation {
      Print[TmpA, OnElementsOf DmnA, File "TmpA-3D.pos"];
      Print[FlxA, OnElementsOf DmnA, File "FlxA-3D.pos"];
      Print[AbsA, OnElementsOf DmnA, File "AbsA-3D.pos"];

      Print[TmpB, OnElementsOf DmnA, File "TmpB-3D.pos"];
      Print[FlxB, OnElementsOf DmnA, File "FlxB-3D.pos"];
      Print[AbsB, OnElementsOf DmnA, File "AbsB-3D.pos"];
    }
  }    
    
  {Name Tmp2D; NameOfPostProcessing TmpPst;
    Operation {
      Print[TmpA,OnLine { {0.0,0.0,0.0} {Rds,0.0,0.0} } {25}, File "TmpA-2D_Btm.pos"];
      Print[TmpA,OnLine { {Rds,0.0,0.0} {Rds,Hgt,0.0} } {25}, File "TmpA-2D_Sde.pos"];
      Print[TmpA,OnLine { {Rds,Hgt,0.0} {0.0,Hgt,0.0} } {25}, File "TmpA-2D_Top.pos"];
      Print[FlxA,OnLine { {0.0,0.0,0.0} {Rds,0.0,0.0} } {25}, File "FlxA-2D_Btm.pos"];
      Print[FlxA,OnLine { {Rds,0.0,0.0} {Rds,Hgt,0.0} } {25}, File "FlxA-2D_Sde.pos"];
      Print[FlxA,OnLine { {Rds,Hgt,0.0} {0.0,Hgt,0.0} } {25}, File "FlxA-2D_Top.pos"];

      Print[TmpB,OnLine { {0.0,Hgt+Sep    ,0.0} {Rds,Hgt+Sep    ,0.0} } {25}, File "TmpB-2D_Btm.pos"];
      Print[TmpB,OnLine { {Rds,Hgt+Sep    ,0.0} {Rds,Hgt+Sep+Hgt,0.0} } {25}, File "TmpB-2D_Sde.pos"];
      Print[TmpB,OnLine { {Rds,Hgt+Sep+Hgt,0.0} {0.0,Hgt+Sep+Hgt,0.0} } {25}, File "TmpB-2D_Top.pos"];
      Print[FlxB,OnLine { {0.0,Hgt+Sep    ,0.0} {Rds,Hgt+Sep    ,0.0} } {25}, File "FlxB-2D_Btm.pos"];
      Print[FlxB,OnLine { {Rds,Hgt+Sep    ,0.0} {Rds,Hgt+Sep+Hgt,0.0} } {25}, File "FlxB-2D_Sde.pos"];
      Print[FlxB,OnLine { {Rds,Hgt+Sep+Hgt,0.0} {0.0,Hgt+Sep+Hgt,0.0} } {25}, File "FlxB-2D_Top.pos"];
    }
  }
}

/* ================================================================== */

