/* === Science & Technology Consultants (SciTeX) = Fri-03-10-3006 === */

/* --- Jacobian (Axisymmetric 2D) ----------------------------------- */

Jacobian {
  {Name JacDmnA;
    Case {
      {Region VolA; Jacobian VolAxi;}
      {Region SfcA; Jacobian SurAxi;}
    }
  }
  {Name JacVolA;
    Case {
      {Region VolA; Jacobian VolAxi;}
    }
  }
  {Name JacSfcA;
    Case {
      {Region SfcA; Jacobian SurAxi;}
    }
  }

  {Name JacDmnB;
    Case {
      {Region VolB; Jacobian VolAxi;}
      {Region SfcB; Jacobian SurAxi;}
    }
  }
  {Name JacVolB;
    Case {
      {Region VolB; Jacobian VolAxi;}
    }
  }
  {Name JacSfcB;
    Case {
      {Region SfcB; Jacobian SurAxi;}
    }
  }
}

/* --- Integration -------------------------------------------------- */

Integration {
  {Name Int;
    Case {
      {Type Gauss;
        Case {
          { GeoElement Point      ; NumberOfPoints  1;}
          { GeoElement Line       ; NumberOfPoints  3;}
          { GeoElement Triangle   ; NumberOfPoints  4;}
          { GeoElement Quadrangle ; NumberOfPoints  4;}
          { GeoElement Tetrahedron; NumberOfPoints  4;}
          { GeoElement Hexahedron ; NumberOfPoints  6;}
          { GeoElement Prism      ; NumberOfPoints  6;}
        }
      }
    }
  }
}

/* --- Function Space ----------------------------------------------- */

FunctionSpace {
  {Name TmpSpcA; Type Form0;
    BasisFunction {
      {Name TmpFctA; NameOfCoef TmpCofA; Function BF_Node; Support DmnA; Entity NodesOf[All];}
    }
    Constraint {
      {NameOfCoef TmpCofA; EntityType NodesOf; NameOfConstraint TmpConA;}
    }
  }

  {Name TmpSpcB; Type Form0;
    BasisFunction {
      {Name TmpFctB; NameOfCoef TmpCofB; Function BF_Node; Support DmnB; Entity NodesOf[All];}
    }
    Constraint {
      {NameOfCoef TmpCofB; EntityType NodesOf; NameOfConstraint TmpConB;}
    }
  }
}

/* --- Formulation -------------------------------------------------- */

Formulation {
  {Name TmpFrm; Type FemEquation;
    Quantity {
      {Name TmpA; Type Local; NameOfSpace TmpSpcA;}
    }
    Equation {
      Galerkin {Dt [MasDen[{TmpA}] * HeaCap[{TmpA}] * Dof{TmpA}, {TmpA}]; 
                In VolA; Integration Int; Jacobian JacVolA;}
  
      Galerkin {[TheCon[{TmpA}] * Dof{d TmpA}, {d TmpA}];
                In VolA; Integration Int; Jacobian JacVolA;}

      Galerkin {[-HeaPwr[], {TmpA}];
                In VolA; Integration Int; Jacobian JacVolA;}

      Galerkin {[-HeaFlx[], {TmpA}];
                In SfcA; Integration Int; Jacobian JacSfcA;}

      Galerkin {[ HTCCvn[{TmpA}] * Dof{TmpA}, {TmpA}];
                In SfcA; Integration Int; Jacobian JacSfcA;}

      Galerkin {[-HTCCvn[{TmpA}] * TmpCvn[], {TmpA}];
                In SfcA; Integration Int; Jacobian JacSfcA;}

      Galerkin {[ HTCRdn[{TmpA}] * ({TmpA})^4, {TmpA}];
                In SfcA; Integration Int; Jacobian JacSfcA;}

      Galerkin {[-HTCRdn[{TmpA}] * (TmpRdn[])^4, {TmpA}];
                In SfcA; Integration Int; Jacobian JacSfcA;}
    }

    Quantity {
      {Name TmpB; Type Local; NameOfSpace TmpSpcB;}
    }
    Equation {
      Galerkin {Dt [MasDen[{TmpB}] * HeaCap[{TmpB}] * Dof{TmpB}, {TmpB}]; 
                In VolB; Integration Int; Jacobian JacVolB;}

      Galerkin {[TheCon[{TmpB}] * Dof{d TmpB}, {d TmpB}];
                In VolB; Integration Int; Jacobian JacVolB;}

      Galerkin {[-HeaPwr[], {TmpB}];
                In VolB; Integration Int; Jacobian JacVolB;}

      Galerkin {[-HeaFlx[], {TmpB}];
                In SfcB; Integration Int; Jacobian JacSfcB;}

      Galerkin {[ HTCCvn[{TmpB}] * Dof{TmpB}, {TmpB}];
                In SfcB; Integration Int; Jacobian JacSfcB;}


// >>> CRITCAL Part <<< !!
      Galerkin {[-HTCCvn[{TmpA}] * TmpA, {TmpB}];
                In SfcA; Integration Int; Jacobian JacSfcA;}
// >>> CRITCAL Part <<< !!


//      Galerkin {[-HTCCvn[{TmpB}] * TmpCvn[], {TmpB}];
//                In SfcB; Integration Int; Jacobian JacSfcB;}

      Galerkin {[ HTCRdn[{TmpB}] * ({TmpB})^4, {TmpB}];
                In SfcB; Integration Int; Jacobian JacSfcB;}

      Galerkin {[-HTCRdn[{TmpB}] * (TmpRdn[])^4, {TmpB}];
                In SfcB; Integration Int; Jacobian JacSfcB;}
    }
  }
}

/* --- Resolution --------------------------------------------------- */

Resolution {
  {Name TmpResNonLin;
    System {
      {Name TmpA; NameOfFormulation TmpFrm;}
      {Name TmpB; NameOfFormulation TmpFrm;}
    }
    Operation {
      InitSolution TmpA;
      InitSolution TmpB;
      IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
        GenerateJac TmpA;
        SolveJac TmpB;
        GenerateJac TmpA;
        SolveJac TmpB;
      }
      SaveSolution TmpA;
      SaveSolution TmpB;
    }
  }

  {Name TmpResLin;
    System {
      {Name TmpA; NameOfFormulation TmpFrm;}
      {Name TmpB; NameOfFormulation TmpFrm;}
    }
    Operation {
      InitSolution TmpA;
      InitSolution TmpB;
      Generate TmpA;
      Generate TmpB;
      Solve TmpA;
      Solve TmpB;
      SaveSolution TmpA;
      SaveSolution TmpB;
    }
  }

  {Name TmpResNonLinTra;
    System {
      {Name TmpA; NameOfFormulation TmpFrm;}
      {Name TmpB; NameOfFormulation TmpFrm;}
    }
    Operation { 
      InitSolution TmpA;
      InitSolution TmpB;
      SaveSolution TmpA;
      SaveSolution TmpB;
      TimeLoopTheta {
        Time0 TmeZro; TimeMax TmeDrn; DTime TmeStp; Theta 1.0;
        Operation {
          IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
            GenerateJac TmpA;
            SolveJac TmpA;
            GenerateJac TmpB;
            SolveJac TmpB;
          }
          Test[SveFct[]] {SaveSolution TmpA;}
          Test[SveFct[]] {SaveSolution TmpB;}
        } 
      } 
    }
  }

  {Name TmpResLinTra;
    System {
      {Name TmpA; NameOfFormulation TmpFrm;}
      {Name TmpB; NameOfFormulation TmpFrm;}
    }
    Operation { 
      InitSolution TmpA;
      InitSolution TmpB;
      SaveSolution TmpA;
      SaveSolution TmpB;
      TimeLoopTheta {
        Time0 TmeZro; TimeMax TmeDrn; DTime TmeStp; Theta 1.0;
        Operation {
          Generate TmpA;
          Solve TmpA;
          Generate TmpB;
          Solve TmpB;
          Test[SveFct[]] {SaveSolution TmpA;}
          Test[SveFct[]] {SaveSolution TmpB;}
        } 
      } 
    }
  }
}

/* --- Post Processing ---------------------------------------------- */

PostProcessing {
  {Name TmpPstA; NameOfFormulation TmpFrmA;
    Quantity {
      {Name Tmp; Value{Local{[{TmpA}]                             ; In DmnA; Jacobian JacDmnA;}}}
      {Name Flx; Value{Local{[-TheCon[{TmpA}] * {Grad TmpA}]      ; In VolA; Jacobian JacVolA;}}}
      {Name Abs; Value{Local{[ TheCon[{TmpA}] * Norm[{Grad TmpA}]]; In VolA; Jacobian JacVolA;}}}
    }
  }

  {Name TmpPstB; NameOfFormulation TmpFrmB;
    Quantity {
      {Name Tmp; Value{Local{[{TmpB}]                             ; In DmnA; Jacobian JacDmnB;}}}
      {Name Flx; Value{Local{[-TheCon[{TmpB}] * {Grad TmpB}]      ; In VolA; Jacobian JacVolB;}}}
      {Name Abs; Value{Local{[ TheCon[{TmpB}] * Norm[{Grad TmpB}]]; In VolA; Jacobian JacVolB;}}}
    }
  }
}

/* ================================================================== */

